@@ -21,7 +21,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.007010';
+our $VERSION = '0.007011';
 $VERSION = eval $VERSION;
 
 use Carp ();
@@ -156,6 +156,7 @@ sub _find_sig {
 }
 
 sub _warn {
+  local $SIG{__WARN__};
   my @convert = _convert(@_);
   if (my $warn = _find_sig($OLD_SIG{__WARN__})) {
     $warn->(join('', @convert));
@@ -224,7 +225,11 @@ our %MESSAGES;
 our %CLONED;
 
 sub CLONE {
-  my %id_map = map { my $ex = $EXCEPTIONS{$_}; $ex ? ($_ => refaddr($ex)) : () } keys %EXCEPTIONS;
+  my %id_map = map {
+    my $ex = $EXCEPTIONS{$_};
+    defined $ex ? ($_ => refaddr($ex)) : ();
+  } keys %EXCEPTIONS;
+
   %EXCEPTIONS = map {; $id_map{$_} => $EXCEPTIONS{$_}} keys %id_map;
   %PACKAGES = map {; $id_map{$_} => $PACKAGES{$_}} keys %id_map;
   %MESSAGES = map {; $id_map{$_} => $MESSAGES{$_}} keys %id_map;
